/*
 * File Name: radio_spi.h
 * 
 * File Contents: a set of macros to support the management of the
 * EasyBee/CC2420 radio transceiver for the Flex Board, 
 * featuring dsPIC33FJ256MC710.
 * 
 * This source code is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * Main documentation: 
 * <CC2420_Data_Sheet_1_3.pdf> The CC2420 datasheet. Available at www.ti.com
 * <EasyBeeDS480.pdf> EasyBee board datasheet. Available at www.rfsolutions.co.uk
 * <Flex_ref_man_027.pdf> Flex reference Manual. Available at www.evidence.eu.com 
 * <70286A.pdf> The dsPIC33 datasheet. Available at www.microchip.com
 * 
 * Further documentation on dsPIC33x can be found at www.microchip.com 
 * 
 * Author: Gianluca Franchino.
 * Affiliation: Retis Lab. Scuola Superiore Sant'Anna. Pisa (Italy).
 * Contacts: g.franchino@sssup.it; gianluca@evidence.eu.com
 * Date: 02/27/2008.
 * 
 */
 

#define __ERIKA__

#ifdef __ERIKA__
#include "ee_internal.h"

#ifndef BYTE
#define BYTE EE_UINT8
#endif

#ifndef WORD
#define WORD EE_UINT16
#endif

#endif

#ifndef __ERIKA__
	#ifdef __dsPIC30F__
		#include <p30fxxxx.h>
	#elifdef __dsPIC33F__
		#include <p33Fxxxx.h>
	#elifdef __PIC24H__
		#include <p24Hxxxx.h>
	#endif
	#ifdef __C30__
		typedef unsigned char BOOL;
		#define FALSE 0x00
		#define TRUE 0x01
	
		typedef unsigned char BYTE; /* 8 bit */
		typedef unsigned int WORD;  /* 16 bit */
		typedef unsigned long DWORD; /* 32 bit */
		typedef unsigned long long QWORD; /* 64 bit */ 
	#endif
#endif

#define RADIO_SPI1 0
#define RADIO_SPI2 1
